local class = require "middleclass"
bouncyBall = class("bouncyBall")

function bouncyBall:initialize(xPosition, yPosition, radius, xVelocity, yVelocity, color, bounceSoundEffect)
	self.position = {xPosition,yPosition}
	self.radius = radius
	self.velocity = {xVelocity, yVelocity}
	self.color = color
	self.bounceSoundEffect = bounceSoundEffect
end
	
function bouncyBall:draw()
	love.graphics.setColor(self.color[1], self.color[2], self.color[3])
	if math.random(0,1) == 1 then 
		love.graphics.circle("fill", self.position[1], self.position[2], self.radius)
	else
		love.graphics.rectangle("fill", self.position[1]-self.radius, self.position[2]-self.radius, self.radius*2, self.radius*2)
	end
end

function bouncyBall:update()
	self:calculateCollisions()
	self:move()
end

function bouncyBall:calculateCollisions()
	local collision = false
	if(self.position[1] + self.radius >= love.graphics.getWidth() or self.position[1] - self.radius <= 0) then
		self.velocity[1] = -self.velocity[1]
		collision = true
	end
	
	if(self.position[2] + self.radius >= love.graphics.getHeight() or self.position[2] - self.radius <= 0) then
		self.velocity[2] = -self.velocity[2]
		collision = true
	end
	
	if collision then
		self:bounceSound()
	end
end

function bouncyBall:move()
	self.position[1] = self.position[1] + self.velocity[1]
	self.position[2] = self.position[2] + self.velocity[2]
end

function bouncyBall:bounceSound()
	self.bounceSoundEffect:play()
end